package com.example.mynotepad.MenuFeatures.AllNotes;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentTransaction;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.room.Room;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Adapter;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

import com.example.mynotepad.MenuFeatures.AllNotes.Note.NoteFragment;
import com.example.mynotepad.MenuFeatures.AllNotes.Note.NoteRecyclerView.MyAdaptor;
import com.example.mynotepad.MenuFeatures.AllNotes.Note.NoteRecyclerView.MyNote;
import com.example.mynotepad.MenuFeatures.AllNotes.NotesDataBase.Note;
import com.example.mynotepad.MenuFeatures.AllNotes.NotesDataBase.NoteDataBase;
import com.example.mynotepad.R;
import com.google.android.material.floatingactionbutton.FloatingActionButton;

import java.util.ArrayList;
import java.util.List;

public class AllNotesActivity extends AppCompatActivity {

    private FrameLayout fragPlace;
    private LinearLayout allNoteListAndTitle;
    private FloatingActionButton addNoteButton;
    private FragmentTransaction fragmentTransaction;
    private CustomToolbarOption customToolbarOption;
    private TextView allNoteToolBar;
    private RecyclerView recyclerView;
    private MyAdaptor myAdaptor;
    private List<Note> notes;
    private List<MyNote> myNotes;
    public static NoteDataBase noteDataBase;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_all_notes);
        init();
    }

    private void init() {
        // get data from database
        noteDataBase = Room.databaseBuilder(this, NoteDataBase.class, "RoomDb").allowMainThreadQueries().build();
        setAllNoteListAndTitles();

        customToolbarOption = findViewById(R.id.customToolbarOption);
        customToolbarOption.setVisibility(View.GONE);
        allNoteToolBar = findViewById(R.id.allNotesToolbar);
        allNoteToolBar.setEnabled(false);
        addNoteButton = findViewById(R.id.addNoteButton);
        allNoteListAndTitle = findViewById(R.id.allNoteListAndTitle);
        fragPlace = findViewById(R.id.fragmentPlace);
        fragPlace.setVisibility(View.GONE);
        addListeners();


        // show list with recycler view
        recyclerView = findViewById(R.id.recyclerView);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this , LinearLayoutManager.VERTICAL , false);
        myAdaptor = new MyAdaptor(myNotes, this);
        recyclerView.setAdapter(myAdaptor);
        recyclerView.setLayoutManager(linearLayoutManager);
    }


    public void addListeners() {
        addNoteButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                showAddAlert();
            }
        });
//todo add listener for long click //update the data base
        //todo add listener to recyclerView
    }


    private void showAddAlert() {
        final AlertDialog.Builder alert = new AlertDialog.Builder(this);
        alert.setTitle("new note :");
        alert.setMessage("Do you want to create a new note ?");
        alert.setCancelable(true);
        alert.setPositiveButton("yes", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                showABlankNote();
            }
        });
        alert.setNegativeButton("no", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialogInterface, int i) {
                dialogInterface.cancel();
            }
        });
        alert.show();
    }

    private void showABlankNote() {
        fragPlace.setVisibility(View.VISIBLE);
        allNoteListAndTitle.setVisibility(View.GONE);
        addNoteButton.hide();

        NoteFragment newNoteFrag = new NoteFragment();
        replaceFragment(newNoteFrag);
    }

    private void showChosenNote() {
        //ToDo replcae fragment and update database
    }

    private void replaceFragment(Fragment fragment) {
        fragmentTransaction = getSupportFragmentManager().beginTransaction();
        fragmentTransaction.replace(fragPlace.getId(), fragment);
        fragmentTransaction.commit();
    }


    private void setAllNoteListAndTitles() {
        notes = noteDataBase.noteDao().getAll();
        myNotes = new ArrayList<>();
        for (Note note : notes) {
            MyNote myNote = new MyNote(note.getTitle() , note.getDescription() , note.isAchieved());
            myNotes.add(myNote);
        }
    }
}